<?php declare(strict_types=1);

namespace Drupal\entity_usage_updater;

/**
 * Supports updating references to entities.
 *
 * It will only update references tracked by the Entity Usage module.
 */
interface EntityUsageUpdaterInterface {

  /**
   * Updates references to entities via the batch API.
   *
   * @param array $mapping
   *   An associative array specifying which entity references to replace. For
   *   example, to update references to node 7946 to 6906, and term 4056 to
   *   4051, pass:
   *   @code
   *   [
   *     'node' => [
   *       7946 => ['node', 6906],
   *     ],
   *     'taxonomy_term' => [
   *       4056 => ['taxonomy_term', 4051],
   *     ],
   *   ];
   *   @endcode
   *   Note that using a different target entity type could lead to invalid
   *   state or errors.
   */
  public function update(array $mapping): void;

}
